@@ -75,11 +75,19 @@ class TableClient:
         ).map(lambda _: ManifestId(f"{prefix}manifest"))
 
     def load(
-        self, table: TableId, manifest: ManifestId, role: str
+        self,
+        table: TableId,
+        manifest: ManifestId,
+        role: str,
+        nan_handler: bool = True,
     ) -> Cmd[None]:
-        stm = """
-            COPY {schema}.{table} FROM %(manifest_file)s
-            iam_role %(role)s MANIFEST ESCAPE
+        """
+        If `nan_handler` is disabled, ensure that the table does not contain NaN values on float columns
+        """
+        nan_fix = "NULL AS 'nan'" if nan_handler else ""
+        stm = f"""
+            COPY {{schema}}.{{table}} FROM %(manifest_file)s
+            iam_role %(role)s MANIFEST ESCAPE {nan_fix}
         """
         return self._db_client.execute(
             dynamic_query(
